import { PanelDetailModel } from './panel-detail';

/**
 * 分页部件模型
 *
 * @export
 * @class PanelTabPanelModel
 * @extends {PanelDetailModel}
 */
export class PanelTabPanelModel extends PanelDetailModel {

    /**
     * 被激活分页
     *
     * @type {string}
     * @memberof PanelTabPanelModel
     */
    public activiedPage: string = '';

    /**
     * 选中激活状态
     *
     * @type {string}
     * @memberof PanelTabPanelModel
     */
    public clickActiviePage: string = '';

    /**
     * 分页子成员
     *
     * @type {string[]}
     * @memberof PanelTabPanelModel
     */
    public details: string[] = [];

    /**
     * Creates an instance of PanelTabPanelModel.
     * PanelTabPanelModel 实例
     * 
     * @param {*} [opts={}]
     * @memberof PanelTabPanelModel
     */
    constructor(opts: any = {}) {
        super(opts);
        this.details = opts.details;
    }

    /**
     * 加载
     *
     * @param {*} context
     * @param {*} viewParams
     * @memberof PanelTabPageModel
     */
    public async load(context: any, viewParams: any) {
        if (!this.parentName) {
            if (this.type == 'VIEWLAYOUT') {
                this.data = {};
            } else {
                this.data = this.panel.data;
            }
        } else {
            let parentItem = this.panel.layoutModelDetails[`${this.parentName}_${this.index}`];
            if (!parentItem) {
                parentItem = this.panel.layoutModelDetails[this.parentName];
            }
            if (parentItem) {
                if (parentItem.dataRegionType === 'MULTIDATA' && parentItem['data'] && parentItem['data'].length > 0) {
                    this.data = parentItem.getData()[this.getIndex()];    
                } else {
                    this.data = parentItem.getData();
                }
            }
        }
    }
}